<template>
  <LoadingLayout>
    <AppContainer>
      <PageFormLayout>
        <template #title>
          <div class="page-form-layout-title">
            申报详情
            <span class="page-form-layout-title-item status">
              审核状态:<span :style="{ color: BountyCheckStatusEnumColor[form.outCheckStatus] }">{{
                BountyCheckStatusEnumText[form.outCheckStatus]
              }}</span>
            </span>
            <span class="page-form-layout-title-item remark">
              <template v-if="form.outCheckStatus === BountyCheckStatusEnum.CheckReject">
                {{ `审核未通过原因:${form.outCheckRemark ?? ''}` }}
              </template>
            </span>
          </div>
        </template>
        <DetailView :form="form">
          <ChunkCellV2 title="申报企业名单">
            <DeclareEnterpriseTableView
              :getList="getList"
              :extra-param-state="extraParamState"
              :pro-table-props="proTableProps"
              :reset="reset"
              :open-dialog="openDialog"
            ></DeclareEnterpriseTableView>
            <MateriaDetailDialog
              v-bind="dialogProps"
              :show-upload-btn="false"
              :show-delete-btn="false"
              :show-check-btn="false"
              downloadBtnText="查看"
            />
          </ChunkCellV2>
        </DetailView>
        <template #footer>
          <el-button @click="handleBack" type="primary">确认</el-button>
        </template>
      </PageFormLayout>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  AppContainer,
  LoadingLayout,
  UploadUserFile,
  PageFormLayout,
  useTable,
  useFormDialog,
} from '@bole-core/components';
import ChunkCellV2 from '@/components/Layout/ChunkCellV2.vue';
import DetailView from '@/components/commonView/DetailView.vue';
import MateriaDetailDialog from '@/components/commonView/MateriaDetailDialog.vue';
import DeclareEnterpriseTableView from '@/components/commonView/DeclareEnterpriseTableView.vue';
import { useQuery } from '@tanstack/vue-query';
import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import { convertApi2FormUrlOnlyOne, setOSSLink } from '@/utils';
import { useRouteView } from '@/hooks';
import { OrderInputType } from '@bole-core/core';
import {
  EnterpriseTypeText,
  BountyCheckStatusEnum,
  BountyCheckStatusEnumText,
  BountyCheckStatusEnumColor,
} from '@/constants';
import { FourStreamsMaterialFileTableItem } from '@/components/commonView/types';
import { FourStreamsMaterialUtils } from '@/components/commonView/utils';
import { useIndustrialParkDropDownList } from '@/hooks/industrialPark';

defineOptions({
  name: 'MaterialReviewDetail',
});

const route = useRoute();
const { closeViewPush } = useRouteView();
const id = route.params?.id as string;
const form = reactive({
  batchNo: '',
  parkName: '',
  parkTypeName: '',
  applyMonth: '',
  applySumAmount: 0,
  enterpriseTaxSubFileUrl: [] as UploadUserFile[],
  enterpriseOperateFileUrl: [] as UploadUserFile[],
  bountyAssignFileUlr: [] as UploadUserFile[],
  bountyCollectFileUrl: [] as UploadUserFile[],

  outCheckStatus: '' as any as BountyCheckStatusEnum,
  outCheckRemark: '',
});

const tableRef = ref<InstanceType<typeof DeclareEnterpriseTableView>>();

const { data: detail, isLoading } = useQuery({
  queryKey: ['parkBountyApplyServices/getOutCheckParkBountyApplyDetailBaseInfo', id],
  queryFn: async () => {
    return await parkBountyApplyServices.getOutCheckParkBountyApplyDetailBaseInfo(
      { parkBountyApplyId: id },
      {
        showLoading: false,
      }
    );
  },
  placeholderData: () => ({} as API.OutCheckParkBountyApplyBaseInfo),
  onSuccess(data) {
    form.batchNo = data.batchNo;
    form.parkName = data.parkName;
    form.parkTypeName = data.parkTypeName;
    form.applyMonth = data.applyMonth;
    form.applySumAmount = data.applySumAmount;
    form.outCheckStatus = data.outCheckStatus;
    form.outCheckRemark = data.outCheckRemark;
    form.enterpriseTaxSubFileUrl = convertApi2FormUrlOnlyOne(data?.enterpriseTaxSubFileUrl);
    form.enterpriseOperateFileUrl = convertApi2FormUrlOnlyOne(data?.enterpriseOperateFileUrl);
    form.bountyAssignFileUlr = convertApi2FormUrlOnlyOne(data?.bountyAssignFileUlr);
    form.bountyCollectFileUrl = convertApi2FormUrlOnlyOne(data?.bountyCollectFileUrl);

    getList();
  },
});

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.GetParkBountyApplyInfoInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        searchKeyWord: extraParamState.searchKeyWord,
        parkBountyApplyId: id,
      };
      let res = await parkBountyApplyServices.getOutCheckParkBountyApplyDetailList(params);
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      orderInput: [{ property: 'parkBountyApplyId', order: OrderInputType.Desc }],
      searchKeyWord: '',
    },
    columnsRenderProps: {
      authType: { type: 'enum', valueEnum: EnterpriseTypeText },
      licenseUrl: {
        type: 'url',
        formatter: (row: API.UserCertificationAuditListDto) => setOSSLink(row.licenseUrl),
        modal: true,
        showDownloadBtn: false,
      },
    },
  }
);

const { dialogProps, handleAdd, editForm } = useFormDialog({
  defaultFormParams: {
    list: [] as FourStreamsMaterialFileTableItem[],
    companyId: '',
  },
});

const { getIndustrialParkTypeNameById } = useIndustrialParkDropDownList();

function openDialog(row: API.ParkBountyApplyDetailInfo) {
  handleAdd({
    list: FourStreamsMaterialUtils.initFourStreamsMaterialFileList(
      row,
      getIndustrialParkTypeNameById(detail.value?.parkId)
    ),
    companyId: row.enterpriseId,
  });
}

function handleBack() {
  closeViewPush(route, {
    name: 'MaterialReviewList',
  });
}
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;

.page-form-layout-title-item {
  margin-left: 16px;
  font-size: 16px;

  &.remark {
    flex: 1;
    min-width: 0;

    @include utils-ellipsis;
  }
}
</style>
